"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var colors = require("colors/safe");
var utils_1 = require("./utils");
function setColours(enabled) {
    colors.enabled = enabled;
}
exports.setColours = setColours;
setColours(false);
function repeat(text, count) {
    var result = '';
    for (var i = 0; i < count; i++) {
        result += text;
    }
    return result;
}
exports.repeat = repeat;
function increaseIndent(text, indent) {
    var indentPadding = repeat(' ', indent);
    return indentPadding + text.split('\n').join('\n' + indentPadding);
}
exports.increaseIndent = increaseIndent;
function pluralise(count, singular, plural) {
    return count + " " + (count === 1 ? singular : plural);
}
exports.pluralise = pluralise;
function formatPath(root, path) {
    return colors.magenta(root) + path
        .map(function (component) {
        if (typeof component === 'number') {
            return colors.yellow('[') + colors.red("" + component) + colors.yellow(']');
        }
        else if (/^[$a-z_][$a-z_0-9]*$/i.test(component)) {
            return colors.yellow('.') + colors.cyan(component);
        }
        else {
            return colors.yellow('[') + colors.red("'" + component.replace('\\', '\\\\').replace('\'', '\\\'') + "'") + colors.yellow(']');
        }
    })
        .join('');
}
exports.formatPath = formatPath;
function formatErrorResultMessage(prefix, root, errors) {
    return colors.white(colors.bgRed(colors.bold("" + prefix + errors.length + " validation error" + (errors.length === 1 ? '' : 's') + ":"))) + '\n' +
        errors.map(function (error) { return increaseIndent(error.toString(root), 4); }).join('\n');
}
exports.formatErrorResultMessage = formatErrorResultMessage;
function formatEitherValidationErrorMessages(errorsPerType) {
    return utils_1.keysOf(errorsPerType)
        .map(function (desc) {
        var errors = errorsPerType[desc];
        return increaseIndent(colors.bold(colors.red("Not " + desc + ", due to " + pluralise(errors.length, 'validation error', 'validation errors') + ":")) + '\n' +
            errors.map(function (error) { return increaseIndent(error.toString(), 4); }).join('\n'), 4);
    })
        .join('\n');
}
exports.formatEitherValidationErrorMessages = formatEitherValidationErrorMessages;
//# sourceMappingURL=formatting.js.map