import { ValidationResult } from './validation-result';
export * from './validation-result';
export { setColours } from './formatting';
export declare type Validator<T> = {
    [key in keyof T]: (arg: any) => ValidationResult<T[key]>;
};
export declare type Validated<T> = {
    [key in keyof T]: T[key];
};
export interface ILength {
    length: number;
}
export interface IValidationOptions {
    allowAdditionalProperties?: boolean;
}
export declare function validate<T>(arg: any, assertion: (arg: any) => ValidationResult<T>): ValidationResult<T>;
export declare function extendValidator<A, B>(validator1: Validator<A>, validator2: Validator<B>): Validator<A & B>;
export declare function extendValidator<A, B, C>(validator1: Validator<A>, validator2: Validator<B>, validator3: Validator<C>): Validator<A & B & C>;
export declare function extendValidator<A, B, C, D>(validator1: Validator<A>, validator2: Validator<B>, validator3: Validator<C>, validator4: Validator<D>): Validator<A & B & C & D>;
export declare function extendValidator<A, B, C, D, E>(validator1: Validator<A>, validator2: Validator<B>, validator3: Validator<C>, validator4: Validator<D>, validator5: Validator<E>): Validator<A & B & C & D & E>;
export declare function extendValidator<A, B, C, D, E, F>(validator1: Validator<A>, validator2: Validator<B>, validator3: Validator<C>, validator4: Validator<D>, validator5: Validator<E>, validator6: Validator<F>): Validator<A & B & C & D & E & F>;
export declare function extendValidator<A, B, C, D, E, F, G>(validator1: Validator<A>, validator2: Validator<B>, validator3: Validator<C>, validator4: Validator<D>, validator5: Validator<E>, validator6: Validator<F>, validator7: Validator<G>): Validator<A & B & C & D & E & F & G>;
export declare function extendValidator<A, B, C, D, E, F, G, H>(validator1: Validator<A>, validator2: Validator<B>, validator3: Validator<C>, validator4: Validator<D>, validator5: Validator<E>, validator6: Validator<F>, validator7: Validator<G>, validator8: Validator<H>): Validator<A & B & C & D & E & F & G & H>;
export declare function extendValidator<A, B, C, D, E, F, G, H, I>(validator1: Validator<A>, validator2: Validator<B>, validator3: Validator<C>, validator4: Validator<D>, validator5: Validator<E>, validator6: Validator<F>, validator7: Validator<G>, validator8: Validator<H>, validator9: Validator<I>): Validator<A & B & C & D & E & F & G & H & I>;
export declare function extendValidator<A, B, C, D, E, F, G, H, I, J>(validator1: Validator<A>, validator2: Validator<B>, validator3: Validator<C>, validator4: Validator<D>, validator5: Validator<E>, validator6: Validator<F>, validator7: Validator<G>, validator8: Validator<H>, validator9: Validator<I>, validator10: Validator<J>): Validator<A & B & C & D & E & F & G & H & I & J>;
export declare function conformsTo<T>(validator: Validator<T>): (arg: any) => ValidationResult<Validated<T>>;
export declare function conformsTo<T>(validator: Validator<T>, options: IValidationOptions): (arg: any) => ValidationResult<Validated<T>>;
export declare function conformsTo<T, U>(validator: Validator<T>, next: (arg: Validated<T>) => ValidationResult<U>): (arg: any) => ValidationResult<U>;
export declare function conformsTo<T, U>(validator: Validator<T>, options: IValidationOptions, next: (arg: Validated<T>) => ValidationResult<U>): (arg: any) => ValidationResult<U>;
export declare function optional(): (arg: any) => ValidationResult<any | undefined>;
export declare function optional<T>(next: (arg: any) => ValidationResult<T>): (arg: any) => ValidationResult<T | undefined>;
export declare function nullable(): (arg: any) => ValidationResult<any | null>;
export declare function nullable<T>(next: (arg: any) => ValidationResult<T>): (arg: any) => ValidationResult<T | null>;
export declare function defaultsTo(def: any): (arg: any) => ValidationResult<any>;
export declare function defaultsTo<T>(def: T, next: (arg: any) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function onErrorDefaultsTo<T, U>(def: U, next: (arg: T) => ValidationResult<U>): (arg: T) => ValidationResult<U>;
export declare function isBoolean(): (arg: any) => ValidationResult<boolean>;
export declare function isBoolean<T = boolean>(next: (arg: boolean) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function isNumber(): (arg: any) => ValidationResult<number>;
export declare function isNumber<T = number>(next: (arg: number) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function min(min: number): (arg: number) => ValidationResult<number>;
export declare function min<T = number>(min: number, next: (arg: number) => ValidationResult<T>): (arg: number) => ValidationResult<T>;
export declare function max(max: number): (arg: number) => ValidationResult<number>;
export declare function max<T = number>(max: number, next: (arg: number) => ValidationResult<T>): (arg: number) => ValidationResult<T>;
export declare function isString(): (arg: any) => ValidationResult<string>;
export declare function isString<T = string>(next: (arg: string) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function matches(regex: RegExp): (arg: string) => ValidationResult<string>;
export declare function matches<T = string>(regex: RegExp, next: (arg: string) => ValidationResult<T>): (arg: string) => ValidationResult<T>;
export declare function minLength<T extends ILength>(min: number): (arg: T) => ValidationResult<T>;
export declare function minLength<T extends ILength, U = T>(min: number, next: (arg: T) => ValidationResult<U>): (arg: T) => ValidationResult<U>;
export declare function maxLength<T extends ILength>(max: number): (arg: T) => ValidationResult<T>;
export declare function maxLength<T extends ILength, U = T>(max: number, next: (arg: T) => ValidationResult<U>): (arg: T) => ValidationResult<U>;
export declare function lengthIs<T extends ILength>(length: number): (arg: T) => ValidationResult<T>;
export declare function lengthIs<T extends ILength, U = T>(length: number, next: (arg: T) => ValidationResult<U>): (arg: T) => ValidationResult<U>;
export declare function isArray(): (arg: any) => ValidationResult<any[]>;
export declare function isArray<T>(next: (arg: any[]) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function eachItem<T>(assertion: (arg: any) => ValidationResult<T>): (arg: any[]) => ValidationResult<T[]>;
export declare function eachItem<T, U>(assertion: (arg: any) => ValidationResult<T>, next: (arg: T[]) => ValidationResult<U>): (arg: any[]) => ValidationResult<U>;
export declare function isObject(): (arg: any) => ValidationResult<any>;
export declare function isObject<T>(next: (arg: any) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function equals<T>(value: T, ...values: T[]): (arg: any) => ValidationResult<T>;
export declare function isMap(): (arg: any) => ValidationResult<{
    [key: string]: any;
}>;
export declare function isMap<T>(next: (arg: {
    [key: string]: any;
}) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function eachValue<T>(assertion: (arg: any) => ValidationResult<T>): (arg: {
    [key: string]: any;
}) => ValidationResult<{
    [key: string]: T;
}>;
export declare function eachValue<T, U>(assertion: (arg: any) => ValidationResult<T>, next: (arg: {
    [key: string]: T;
}) => ValidationResult<U>): (arg: {
    [key: string]: any;
}) => ValidationResult<U>;
export interface IEitherOption<T> {
    description: string;
    assertion: (arg: any) => ValidationResult<T>;
}
export declare function is<T>(description: string, assertion: (arg: any) => ValidationResult<T>): IEitherOption<T>;
export declare function either<A, B>(option1: IEitherOption<A>, option2: IEitherOption<B>): (arg: any) => ValidationResult<A | B>;
export declare function either<A, B, C>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>): (arg: any) => ValidationResult<A | B | C>;
export declare function either<A, B, C, D>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>): (arg: any) => ValidationResult<A | B | C | D>;
export declare function either<A, B, C, D, E>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>): (arg: any) => ValidationResult<A | B | C | D | E>;
export declare function either<A, B, C, D, E, F>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>): (arg: any) => ValidationResult<A | B | C | D | E | F>;
export declare function either<A, B, C, D, E, F, G>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>): (arg: any) => ValidationResult<A | B | C | D | E | F | G>;
export declare function either<A, B, C, D, E, F, G, H>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H>;
export declare function either<A, B, C, D, E, F, G, H, I>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I>;
export declare function either<A, B, C, D, E, F, G, H, I, J>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>, option10: IEitherOption<J>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I | J>;
export declare function either<A, B, C, D, E, F, G, H, I, J, K>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>, option10: IEitherOption<J>, option11: IEitherOption<K>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I | J | K>;
export declare function either<A, B, C, D, E, F, G, H, I, J, K, L>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>, option10: IEitherOption<J>, option11: IEitherOption<K>, option12: IEitherOption<L>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I | J | K | L>;
export declare function either<A, B, C, D, E, F, G, H, I, J, K, L, M>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>, option10: IEitherOption<J>, option11: IEitherOption<K>, option12: IEitherOption<L>, option13: IEitherOption<M>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I | J | K | L | M>;
export declare function either<A, B, C, D, E, F, G, H, I, J, K, L, M, N>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>, option10: IEitherOption<J>, option11: IEitherOption<K>, option12: IEitherOption<L>, option13: IEitherOption<M>, option14: IEitherOption<N>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I | J | K | L | M | N>;
export declare function either<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>, option10: IEitherOption<J>, option11: IEitherOption<K>, option12: IEitherOption<L>, option13: IEitherOption<M>, option14: IEitherOption<N>, option15: IEitherOption<O>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I | J | K | L | M | N | O>;
export declare function either<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>, option10: IEitherOption<J>, option11: IEitherOption<K>, option12: IEitherOption<L>, option13: IEitherOption<M>, option14: IEitherOption<N>, option15: IEitherOption<O>, option16: IEitherOption<P>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I | J | K | L | M | N | O | P>;
export declare function either<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>, option10: IEitherOption<J>, option11: IEitherOption<K>, option12: IEitherOption<L>, option13: IEitherOption<M>, option14: IEitherOption<N>, option15: IEitherOption<O>, option16: IEitherOption<P>, option17: IEitherOption<Q>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I | J | K | L | M | N | O | P | Q>;
export declare function either<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>, option10: IEitherOption<J>, option11: IEitherOption<K>, option12: IEitherOption<L>, option13: IEitherOption<M>, option14: IEitherOption<N>, option15: IEitherOption<O>, option16: IEitherOption<P>, option17: IEitherOption<Q>, option18: IEitherOption<R>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I | J | K | L | M | N | O | P | Q | R>;
export declare function either<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>, option10: IEitherOption<J>, option11: IEitherOption<K>, option12: IEitherOption<L>, option13: IEitherOption<M>, option14: IEitherOption<N>, option15: IEitherOption<O>, option16: IEitherOption<P>, option17: IEitherOption<Q>, option18: IEitherOption<R>, option19: IEitherOption<S>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I | J | K | L | M | N | O | P | Q | R | S>;
export declare function either<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T>(option1: IEitherOption<A>, option2: IEitherOption<B>, option3: IEitherOption<C>, option4: IEitherOption<D>, option5: IEitherOption<E>, option6: IEitherOption<F>, option7: IEitherOption<G>, option8: IEitherOption<H>, option9: IEitherOption<I>, option10: IEitherOption<J>, option11: IEitherOption<K>, option12: IEitherOption<L>, option13: IEitherOption<M>, option14: IEitherOption<N>, option15: IEitherOption<O>, option16: IEitherOption<P>, option17: IEitherOption<Q>, option18: IEitherOption<R>, option19: IEitherOption<S>, option20: IEitherOption<T>): (arg: any) => ValidationResult<A | B | C | D | E | F | G | H | I | J | K | L | M | N | O | P | Q | R | S | T>;
