export declare type ValidationResult<T> = SuccessResult<T> | ErrorResult;
export declare class ValidationError {
    readonly errorCode: string;
    readonly message: string;
    readonly path: Array<string | number>;
    constructor(errorCode: string, message: string);
    addPathSegment(seg: string | number): ValidationError;
    toString(root?: string): string;
    pathString(root?: string): string;
}
export declare class EitherValidationError extends ValidationError {
    readonly errors: {
        [description: string]: ValidationError[];
    };
    constructor();
    toString(root?: string): string;
}
export declare class ErrorResult {
    readonly success: false;
    readonly errors: ValidationError[];
    constructor(errors: ValidationError | ValidationError[]);
    addPathSegment(seg: string | number): ErrorResult;
    toString(root?: string, prefix?: string): string;
    static isErrorResult(arg: any): arg is ErrorResult;
}
export interface SuccessResult<T> {
    readonly success: true;
    readonly value: T;
}
export declare function error(errorCode: string, message: string): ErrorResult;
export declare function errorFromException(err: any): ErrorResult;
export declare function success<T>(value: T): SuccessResult<T>;
