"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var formatting_1 = require("./formatting");
var ValidationError = /** @class */ (function () {
    function ValidationError(errorCode, message) {
        this.errorCode = errorCode;
        this.message = message;
        this.path = [];
    }
    ValidationError.prototype.addPathSegment = function (seg) {
        this.path.unshift(seg);
        return this;
    };
    ValidationError.prototype.toString = function (root) {
        if (root === void 0) { root = '$'; }
        return this.pathString(root) + ": " + this.message;
    };
    ValidationError.prototype.pathString = function (root) {
        if (root === void 0) { root = '$'; }
        return formatting_1.formatPath(root, this.path);
    };
    return ValidationError;
}());
exports.ValidationError = ValidationError;
var EitherValidationError = /** @class */ (function (_super) {
    __extends(EitherValidationError, _super);
    function EitherValidationError() {
        var _this = _super.call(this, 'NO_MATCH', 'No match found') || this;
        _this.errors = {};
        return _this;
    }
    EitherValidationError.prototype.toString = function (root) {
        if (root === void 0) { root = '$'; }
        return this.pathString(root) + ": " + this.message + " - the following assertions failed:\n" + formatting_1.formatEitherValidationErrorMessages(this.errors);
    };
    return EitherValidationError;
}(ValidationError));
exports.EitherValidationError = EitherValidationError;
var ErrorResult = /** @class */ (function () {
    function ErrorResult(errors) {
        this.success = false;
        if (errors instanceof ValidationError) {
            this.errors = [errors];
        }
        else {
            this.errors = errors;
        }
    }
    ErrorResult.prototype.addPathSegment = function (seg) {
        for (var _i = 0, _a = this.errors; _i < _a.length; _i++) {
            var error_1 = _a[_i];
            error_1.addPathSegment(seg);
        }
        return this;
    };
    ErrorResult.prototype.toString = function (root, prefix) {
        if (root === void 0) { root = '$'; }
        if (prefix === void 0) { prefix = ''; }
        return formatting_1.formatErrorResultMessage(prefix, root, this.errors);
    };
    ErrorResult.isErrorResult = function (arg) {
        return arg instanceof ErrorResult;
    };
    return ErrorResult;
}());
exports.ErrorResult = ErrorResult;
function error(errorCode, message) {
    return new ErrorResult(new ValidationError(errorCode, message));
}
exports.error = error;
function errorFromException(err) {
    return new ErrorResult(new ValidationError('UNHANDLED_ERROR', "Unhandled error: " + (typeof err === 'object' && err.message || 'Unknown error')));
}
exports.errorFromException = errorFromException;
function success(value) {
    return { success: true, value: value };
}
exports.success = success;
//# sourceMappingURL=validation-result.js.map